@@ -1,5 +1,6 @@
 from .base import BaseCommand
 from .base import ExecutionManager
+from .base import SimpleExecutionManager
 from .base import LabelCommand
 from .base import Parser
 from .base import SingleLabelCommand
@@ -7,10 +8,14 @@ from .base import arg
 from .completion import CompletionCommand
 
 
-__all__ = ['ExecutionManager', 'arg',
+__all__ = [
+    'ExecutionManager',
+    'SimpleExecutionManager',
+    'arg',
     'Parser',
     'BaseCommand',
-    'LabelCommand', 'SingleLabelCommand',
+    'LabelCommand',
+    'SingleLabelCommand',
     'CompletionCommand',
 ]
 
